# VideoHandler

```python
import pynapple as nap
import pynaviz as viz

print(videohandler)
```
```
<pynaviz.audiovideo.video_handling.VideoHandler object at 0x152d819b3c10>
```

---
## PlotVideoHandler                    

```python
v = viz.PlotVideoHandler(videohandler)

v.show()
```
![None](/_static/screenshots/test_plot_videohandler.png)

                    